ChannelConverter

Struct ChannelConverter 

pub struct ChannelConverter<T: SoundSource> { /* private fields */ }
Convert a SoundSource to a diferent number of channels.

If the number of channels in the inner SoundSource is equal to the output number of channels, no conversion will be performed. Otherwise, each channel of the output will receive the average of all input channels.

Implementations

Source

impl<T: SoundSource> ChannelConverter<T>

pub fn new(inner: T, channels: u16) -> Self

Create a new ChannelConverter.

This will convert from the number of channels of inner, outputing the given number of channels.